********************************************
*
*  This is the SPSS syntax file used for
*  my APSA08 paper titled "Have you really 
*  not participated?"
*
*  The file uses three SPSS datasets:
*   1) jeds2000r3.sav
*   2) Glope2005-07_pre-release_v1-071021.sav
*   3) Waseda-CASI2007_pre-release_v071227.sav
*
*  (c)2008 by Yoshitaka Nishizawa and 
*             Koichi Kuriyama 
*
********************************************.

***          ***
*** jeds2000 ***
***          ***.

get file='jeds2000r3.sav'.

*** Figure 1.

missing values a26a to a26o a28a to a28o (7,8).
fre a26a a26c a26i a26j a26k a26l a26o
    a28a a28c a28i a28j a28k a28l a28o.


***              ***
*** Glope2005-07 ***
***              ***.

get file='Glope2005-07_pre-release_v1-071021.sav'.

recode b13a1 b13a2 b13a3 b13a4 b13a5 b13a6 b13a7 b13a8
  (1=3)(2=1.5)(3=0)(else=9) into
  ppt1 to ppt8.
recode b13b1 b13b2 b13b3 b13b4 b13b5 b13b6 b13b7 b13b8
  (1=1)(2=-1)(else=9) into
  ret1 to ret8.
missing values ppt1 to ppt8 ret1 to ret8 (9).


*** Table 1.

sort cases by casi_papi.
temporary.
split file by casi_papi.
fre ppt1 to ppt8 ret1 to ret8.

t-test
  groups=casi_papi(0 1)
 /var
 ppt1 to ppt8 ret1 to ret8.

npar tests m-w=
 ppt1 to ppt8 ret1 to ret8
 by
 casi_papi (0,1).
 


***                 ***
*** Waseda-CASI2007 ***
***                 ***.

get file='Waseda-CASI2007_pre-release_v071227.sav'.

*** willingness and retreatedness.

recode 
 b15a1  b15a2  b15a3  b15a4  b15a5  b15a6  b15a7  b15a8 
 b15a9  b15a10 b15a11 b15a12 b15a13 b15a14 b15a15 b15a16 
(1=3)(2=1.5)(3=0)(else=9) into
 pp1  pp2  pp3  pp4  pp5  pp6  pp7  pp8
 pp9  pp10 pp11 pp12 pp13 pp14 pp15 pp16. 
recode 
 b15b1  b15b2  b15b3  b15b4  b15b5  b15b6  b15b7  b15b8 
 b15b9  b15b10 b15b11 b15b12 b15b13 b15b14 b15b15 b15b16 
(1=1)(2=0)(3=-1)(else=9) into
 wl1  wl2  wl3  wl4  wl5  wl6  wl7  wl8
 wl9  wl10 wl11 wl12 wl13 wl14 wl15 wl16. 
missing values
 pp1  pp2  pp3  pp4  pp5  pp6  pp7  pp8
 pp9  pp10 pp11 pp12 pp13 pp14 pp15 pp16 
 wl1  wl2  wl3  wl4  wl5  wl6  wl7  wl8
 wl9  wl10 wl11 wl12 wl13 wl14 wl15 wl16
(9). 

** saving missing cases, by replacing missing with the mean.
compute nOFmissing=nmiss(
 pp1,pp2,pp3,pp4,pp5,pp6,pp7,pp8,
 pp9,pp10,pp11,pp12,pp13,pp14,pp15,pp16). 
 
compute m_V=mean.2(
 pp1,pp2,pp3,pp4,pp5,pp6,pp7,pp8,
 pp9,pp10,pp11,pp12,pp13,pp14,pp15,pp16). 

do repeat
  V  = pp1,pp2,pp3,pp4,pp5,pp6,pp7,pp8,
       pp9,pp10,pp11,pp12,pp13,pp14,pp15,pp16 
 /ajV= ajpp1,ajpp2,ajpp3,ajpp4,ajpp5,ajpp6,ajpp7,ajpp8,
       ajpp9,ajpp10,ajpp11,ajpp12,ajpp13,ajpp14,ajpp15,ajpp16 
 /um = um1,um2,um3,um4,um5,um6,um7,um8,
       um9,um10,um11,um12,um13,um14,um15,um16.
 compute um=missing(V).
 do if (um eq 1 and nOFmissing le 14).
   compute ajV = m_V.
 else.
   compute ajV = V.
 end if.
end repeat.

** saving missing cases, by replacing missing with the mean.
compute nOFmissing=nmiss(
 wl1,wl2,wl3,wl4,wl5,wl6,wl7,wl8,
 wl9,wl10,wl11,wl12,wl13,wl14,wl15,wl16). 
 
compute m_V=mean.2(
 wl1,wl2,wl3,wl4,wl5,wl6,wl7,wl8,
 wl9,wl10,wl11,wl12,wl13,wl14,wl15,wl16). 

do repeat
  V  = wl1,wl2,wl3,wl4,wl5,wl6,wl7,wl8,
       wl9,wl10,wl11,wl12,wl13,wl14,wl15,wl16 
 /ajV= ajwl1,ajwl2,ajwl3,ajwl4,ajwl5,ajwl6,ajwl7,ajwl8,
       ajwl9,ajwl10,ajwl11,ajwl12,ajwl13,ajwl14,ajwl15,ajwl16 
 /um = um1,um2,um3,um4,um5,um6,um7,um8,
       um9,um10,um11,um12,um13,um14,um15,um16.
 compute um=missing(V).
 do if (um eq 1 and nOFmissing le 14).
   compute ajV = m_V.
 else.
   compute ajV = V.
 end if.
end repeat.


*** political attitude.

recode a3 (1=1)(2=.67)(3=.33)(4=0)(else=9) into
 polintA.
missing values polintA (9).

recode a33a a33b a33d a33e (1=0)(2=.25)(3=.5)(4=.75)(5=1)(else=9) into
 efc1 efc2 efc3 efc4.
recode a33c a33f (1=1)(2=.75)(3=.5)(4=.25)(5=0)(else=9) into
 duty efc5.
missing values efc1 to efc5 duty (9).


** saving missing cases, by replacing missing with the mean.
compute nOFmissing=nmiss(
 efc1,efc2,efc3,efc4,efc5). 
 
compute m_V=mean.2(
 efc1,efc2,efc3,efc4,efc5). 

do repeat
  V  =efc1,efc2,efc3,efc4,efc5 
 /ajV=ajefc1,ajefc2,ajefc3,ajefc4,ajefc5 
 /um = um1,um2,um3,um4,um5.
 compute um=missing(V).
 do if (um eq 1 and nOFmissing le 3).
   compute ajV = m_V.
 else.
   compute ajV = V.
 end if.
end repeat.


execute.


*** Table 2.

temporary.
split file by casipapi.
freq
 pp1  pp2  pp3  pp4  pp5  pp6  pp7  pp8
 pp9  pp10 pp11 pp12 pp13 pp14 pp15 pp16 
 wl1  wl2  wl3  wl4  wl5  wl6  wl7  wl8
 wl9  wl10 wl11 wl12 wl13 wl14 wl15 wl16.

t-test
  groups=casipapi(1 2)
 /var
 pp1  pp2  pp3  pp4  pp5  pp6  pp7  pp8
 pp9  pp10 pp11 pp12 pp13 pp14 pp15 pp16 
 wl1  wl2  wl3  wl4  wl5  wl6  wl7  wl8
 wl9  wl10 wl11 wl12 wl13 wl14 wl15 wl16.

npar tests m-w=
 pp1  pp2  pp3  pp4  pp5  pp6  pp7  pp8
 pp9  pp10 pp11 pp12 pp13 pp14 pp15 pp16 
 wl1  wl2  wl3  wl4  wl5  wl6  wl7  wl8
 wl9  wl10 wl11 wl12 wl13 wl14 wl15 wl16
 by
 casipapi (1,2).


*** Table 3.

** pid.
recode a9 (1 thru 6=1)(7=0)(else=9) into pid.
missing values pid (9).

temporary.
split file by casipapi.
freq pid.

t-test
  groups=casipapi(1 2)
 /var pid.


** party never vote for.
recode a10xNON (1=0)(0=1)(else=9) into neverV.
missing values neverV (9).

temporary.
split file by casipapi.
freq neverV.

t-test
  groups=casipapi(1 2)
 /var neverV.


**undecided.
recode a14 a15 (1 thru 6=0)(7=1)(else=9)
 into undecE undecP.
missing values undecE undecP (9).

temporary.
split file by casipapi.
freq
 undecE undecP.

t-test
  groups=casipapi(1 2)
 /var undecE undecP.



*** Figure 3 (data extraction for ESM).
**    Note that the extracted file are spss system files.
**    They need to be converted to tab delimitered data 
**    files before being used with Mplus.

compute compSet01=nmiss(
 polintA,
 ajefc1,ajefc2,ajefc3,ajefc4,ajefc5,
 duty, 
 ajpp1,ajpp2,ajpp3,ajpp4,ajpp5,ajpp6,ajpp7,ajpp8,
 ajpp9,ajpp10,ajpp11,ajpp12,ajpp13,ajpp14,ajpp15,ajpp16, 
 ajwl1,ajwl2,ajwl3,ajwl4,ajwl5,ajwl6,ajwl7,ajwl8,
 ajwl9,ajwl10,ajwl11,ajwl12,ajwl13,ajwl14,ajwl15,ajwl16
).
compute good=0.
if (compSet01=0) good=1.

temporary.
select if (good eq 1 and wave eq 1).
save outfile='apsa08v7-casi.sav'
 /keep
 polintA,
 ajefc1,ajefc2,ajefc3,ajefc4,ajefc5,
 duty, 
 ajpp1,ajpp2,ajpp3,ajpp4,ajpp5,ajpp6,ajpp7,ajpp8,
 ajpp9,ajpp10,ajpp11,ajpp12,ajpp13,ajpp14,ajpp15,ajpp16, 
 ajwl1,ajwl2,ajwl3,ajwl4,ajwl5,ajwl6,ajwl7,ajwl8,
 ajwl9,ajwl10,ajwl11,ajwl12,ajwl13,ajwl14,ajwl15,ajwl16
.

temporary.
select if (good eq 1 and wave eq 4).
save outfile='apsa08v7-papi.sav'
 /keep
 polintA,
 ajefc1,ajefc2,ajefc3,ajefc4,ajefc5,
 duty, 
 ajpp1,ajpp2,ajpp3,ajpp4,ajpp5,ajpp6,ajpp7,ajpp8,
 ajpp9,ajpp10,ajpp11,ajpp12,ajpp13,ajpp14,ajpp15,ajpp16, 
 ajwl1,ajwl2,ajwl3,ajwl4,ajwl5,ajwl6,ajwl7,ajwl8,
 ajwl9,ajwl10,ajwl11,ajwl12,ajwl13,ajwl14,ajwl15,ajwl16
.

*end of file.